@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0060';
+our $VERSION = '0.0061';
 
 use Moo;
 use strictures 2;
@@ -399,7 +399,8 @@ sub graphviz {
     for my $parameter (@{ $sets{$from} }) {
       next if $parameter->{control} eq 'patch';
       my $label = "$parameter->{param} = $parameter->{value}$parameter->{unit}";
-      push @labels, $label unless $seen{$label}++;
+      my $key   = "$from $label";
+      push @labels, $label unless $seen{$key}++;
     }
     $labels{$from} = join "\n", $from, @labels;
   }
@@ -451,7 +452,7 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0060
+version 0.0061
 
 =head1 SYNOPSIS
 
